# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Observer.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Glacier2_Session_ice
import IceGrid_Exception_ice
import IceGrid_Descriptor_ice
import IceGrid_Admin_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module IceGrid
_M_IceGrid = Ice.openModule('IceGrid')

# Start of module IceGrid
__name__ = 'IceGrid'

if 'ServerDynamicInfo' not in _M_IceGrid.__dict__:
    _M_IceGrid.ServerDynamicInfo = Ice.createTempClass()
    class ServerDynamicInfo(object):
        """
        Dynamic information about the state of a server.
        Members:
        id -- The id of the server.
        state -- The state of the server.
        pid -- The process id of the server.
        enabled -- Indicates whether the server is enabled.
        """
        def __init__(self, id='', state=_M_IceGrid.ServerState.Inactive, pid=0, enabled=False):
            self.id = id
            self.state = state
            self.pid = pid
            self.enabled = enabled

        def __hash__(self):
            _h = 0
            _h = 5 * _h + Ice.getHash(self.id)
            _h = 5 * _h + Ice.getHash(self.state)
            _h = 5 * _h + Ice.getHash(self.pid)
            _h = 5 * _h + Ice.getHash(self.enabled)
            return _h % 0x7fffffff

        def __compare(self, other):
            if other is None:
                return 1
            elif not isinstance(other, _M_IceGrid.ServerDynamicInfo):
                return NotImplemented
            else:
                if self.id is None or other.id is None:
                    if self.id != other.id:
                        return (-1 if self.id is None else 1)
                else:
                    if self.id < other.id:
                        return -1
                    elif self.id > other.id:
                        return 1
                if self.state is None or other.state is None:
                    if self.state != other.state:
                        return (-1 if self.state is None else 1)
                else:
                    if self.state < other.state:
                        return -1
                    elif self.state > other.state:
                        return 1
                if self.pid is None or other.pid is None:
                    if self.pid != other.pid:
                        return (-1 if self.pid is None else 1)
                else:
                    if self.pid < other.pid:
                        return -1
                    elif self.pid > other.pid:
                        return 1
                if self.enabled is None or other.enabled is None:
                    if self.enabled != other.enabled:
                        return (-1 if self.enabled is None else 1)
                else:
                    if self.enabled < other.enabled:
                        return -1
                    elif self.enabled > other.enabled:
                        return 1
                return 0

        def __lt__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r < 0

        def __le__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r <= 0

        def __gt__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r > 0

        def __ge__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r >= 0

        def __eq__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r == 0

        def __ne__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r != 0

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_ServerDynamicInfo)

        __repr__ = __str__

    _M_IceGrid._t_ServerDynamicInfo = IcePy.defineStruct('::IceGrid::ServerDynamicInfo', ServerDynamicInfo, (), (
        ('id', (), IcePy._t_string),
        ('state', (), _M_IceGrid._t_ServerState),
        ('pid', (), IcePy._t_int),
        ('enabled', (), IcePy._t_bool)
    ))

    _M_IceGrid.ServerDynamicInfo = ServerDynamicInfo
    del ServerDynamicInfo

if '_t_ServerDynamicInfoSeq' not in _M_IceGrid.__dict__:
    _M_IceGrid._t_ServerDynamicInfoSeq = IcePy.defineSequence('::IceGrid::ServerDynamicInfoSeq', (), _M_IceGrid._t_ServerDynamicInfo)

if 'AdapterDynamicInfo' not in _M_IceGrid.__dict__:
    _M_IceGrid.AdapterDynamicInfo = Ice.createTempClass()
    class AdapterDynamicInfo(object):
        """
        Dynamic information about the state of an adapter.
        Members:
        id -- The id of the adapter.
        proxy -- The direct proxy containing the adapter endpoints.
        """
        def __init__(self, id='', proxy=None):
            self.id = id
            self.proxy = proxy

        def __eq__(self, other):
            if other is None:
                return False
            elif not isinstance(other, _M_IceGrid.AdapterDynamicInfo):
                return NotImplemented
            else:
                if self.id != other.id:
                    return False
                if self.proxy != other.proxy:
                    return False
                return True

        def __ne__(self, other):
            return not self.__eq__(other)

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_AdapterDynamicInfo)

        __repr__ = __str__

    _M_IceGrid._t_AdapterDynamicInfo = IcePy.defineStruct('::IceGrid::AdapterDynamicInfo', AdapterDynamicInfo, (), (
        ('id', (), IcePy._t_string),
        ('proxy', (), IcePy._t_ObjectPrx)
    ))

    _M_IceGrid.AdapterDynamicInfo = AdapterDynamicInfo
    del AdapterDynamicInfo

if '_t_AdapterDynamicInfoSeq' not in _M_IceGrid.__dict__:
    _M_IceGrid._t_AdapterDynamicInfoSeq = IcePy.defineSequence('::IceGrid::AdapterDynamicInfoSeq', (), _M_IceGrid._t_AdapterDynamicInfo)

if 'NodeDynamicInfo' not in _M_IceGrid.__dict__:
    _M_IceGrid.NodeDynamicInfo = Ice.createTempClass()
    class NodeDynamicInfo(object):
        """
        Dynamic information about the state of a node.
        Members:
        info -- Some static information about the node.
        servers -- The dynamic information of the servers deployed on this node.
        adapters -- The dynamic information of the adapters deployed on this node.
        """
        def __init__(self, info=Ice._struct_marker, servers=None, adapters=None):
            if info is Ice._struct_marker:
                self.info = _M_IceGrid.NodeInfo()
            else:
                self.info = info
            self.servers = servers
            self.adapters = adapters

        def __eq__(self, other):
            if other is None:
                return False
            elif not isinstance(other, _M_IceGrid.NodeDynamicInfo):
                return NotImplemented
            else:
                if self.info != other.info:
                    return False
                if self.servers != other.servers:
                    return False
                if self.adapters != other.adapters:
                    return False
                return True

        def __ne__(self, other):
            return not self.__eq__(other)

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_NodeDynamicInfo)

        __repr__ = __str__

    _M_IceGrid._t_NodeDynamicInfo = IcePy.defineStruct('::IceGrid::NodeDynamicInfo', NodeDynamicInfo, (), (
        ('info', (), _M_IceGrid._t_NodeInfo),
        ('servers', (), _M_IceGrid._t_ServerDynamicInfoSeq),
        ('adapters', (), _M_IceGrid._t_AdapterDynamicInfoSeq)
    ))

    _M_IceGrid.NodeDynamicInfo = NodeDynamicInfo
    del NodeDynamicInfo

if '_t_NodeDynamicInfoSeq' not in _M_IceGrid.__dict__:
    _M_IceGrid._t_NodeDynamicInfoSeq = IcePy.defineSequence('::IceGrid::NodeDynamicInfoSeq', (), _M_IceGrid._t_NodeDynamicInfo)

if 'NodeObserver' not in _M_IceGrid.__dict__:
    _M_IceGrid.NodeObserver = Ice.createTempClass()
    class NodeObserver(Ice.Object):
        """
        The node observer interface. Observers should implement this
        interface to receive information about the state of the IceGrid
        nodes.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.NodeObserver:
                raise RuntimeError('IceGrid.NodeObserver is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::NodeObserver')

        def ice_id(self, current=None):
            return '::IceGrid::NodeObserver'

        def ice_staticId():
            return '::IceGrid::NodeObserver'
        ice_staticId = staticmethod(ice_staticId)

        def nodeInit(self, nodes, current=None):
            """
            The nodeInit operation indicates the current state
            of nodes. It is called after the registration of an observer.
            Arguments:
            nodes -- The current state of the nodes.
            current -- The Current object for the invocation.
            """
            pass

        def nodeUp(self, node, current=None):
            """
            The nodeUp operation is called to notify an observer that a node
            came up.
            Arguments:
            node -- The node state.
            current -- The Current object for the invocation.
            """
            pass

        def nodeDown(self, name, current=None):
            """
            The nodeDown operation is called to notify an observer that a node
            went down.
            Arguments:
            name -- The node name.
            current -- The Current object for the invocation.
            """
            pass

        def updateServer(self, node, updatedInfo, current=None):
            """
            The updateServer operation is called to notify an observer that
            the state of a server changed.
            Arguments:
            node -- The node hosting the server.
            updatedInfo -- The new server state.
            current -- The Current object for the invocation.
            """
            pass

        def updateAdapter(self, node, updatedInfo, current=None):
            """
            The updateAdapter operation is called to notify an observer that
            the state of an adapter changed.
            Arguments:
            node -- The node hosting the adapter.
            updatedInfo -- The new adapter state.
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_NodeObserver)

        __repr__ = __str__

    _M_IceGrid.NodeObserverPrx = Ice.createTempClass()
    class NodeObserverPrx(Ice.ObjectPrx):

        """
        The nodeInit operation indicates the current state
        of nodes. It is called after the registration of an observer.
        Arguments:
        nodes -- The current state of the nodes.
        _ctx -- The request context for the invocation.
        """
        def nodeInit(self, nodes, _ctx=None):
            return _M_IceGrid.NodeObserver._op_nodeInit.invoke(self, ((nodes, ), _ctx))

        """
        The nodeInit operation indicates the current state
        of nodes. It is called after the registration of an observer.
        Arguments:
        nodes -- The current state of the nodes.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_nodeInit(self, nodes, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.NodeObserver._op_nodeInit.begin(self, ((nodes, ), _response, _ex, _sent, _ctx))

        """
        The nodeInit operation indicates the current state
        of nodes. It is called after the registration of an observer.
        Arguments:
        nodes -- The current state of the nodes.
        """
        def end_nodeInit(self, _r):
            return _M_IceGrid.NodeObserver._op_nodeInit.end(self, _r)

        """
        The nodeUp operation is called to notify an observer that a node
        came up.
        Arguments:
        node -- The node state.
        _ctx -- The request context for the invocation.
        """
        def nodeUp(self, node, _ctx=None):
            return _M_IceGrid.NodeObserver._op_nodeUp.invoke(self, ((node, ), _ctx))

        """
        The nodeUp operation is called to notify an observer that a node
        came up.
        Arguments:
        node -- The node state.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_nodeUp(self, node, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.NodeObserver._op_nodeUp.begin(self, ((node, ), _response, _ex, _sent, _ctx))

        """
        The nodeUp operation is called to notify an observer that a node
        came up.
        Arguments:
        node -- The node state.
        """
        def end_nodeUp(self, _r):
            return _M_IceGrid.NodeObserver._op_nodeUp.end(self, _r)

        """
        The nodeDown operation is called to notify an observer that a node
        went down.
        Arguments:
        name -- The node name.
        _ctx -- The request context for the invocation.
        """
        def nodeDown(self, name, _ctx=None):
            return _M_IceGrid.NodeObserver._op_nodeDown.invoke(self, ((name, ), _ctx))

        """
        The nodeDown operation is called to notify an observer that a node
        went down.
        Arguments:
        name -- The node name.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_nodeDown(self, name, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.NodeObserver._op_nodeDown.begin(self, ((name, ), _response, _ex, _sent, _ctx))

        """
        The nodeDown operation is called to notify an observer that a node
        went down.
        Arguments:
        name -- The node name.
        """
        def end_nodeDown(self, _r):
            return _M_IceGrid.NodeObserver._op_nodeDown.end(self, _r)

        """
        The updateServer operation is called to notify an observer that
        the state of a server changed.
        Arguments:
        node -- The node hosting the server.
        updatedInfo -- The new server state.
        _ctx -- The request context for the invocation.
        """
        def updateServer(self, node, updatedInfo, _ctx=None):
            return _M_IceGrid.NodeObserver._op_updateServer.invoke(self, ((node, updatedInfo), _ctx))

        """
        The updateServer operation is called to notify an observer that
        the state of a server changed.
        Arguments:
        node -- The node hosting the server.
        updatedInfo -- The new server state.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_updateServer(self, node, updatedInfo, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.NodeObserver._op_updateServer.begin(self, ((node, updatedInfo), _response, _ex, _sent, _ctx))

        """
        The updateServer operation is called to notify an observer that
        the state of a server changed.
        Arguments:
        node -- The node hosting the server.
        updatedInfo -- The new server state.
        """
        def end_updateServer(self, _r):
            return _M_IceGrid.NodeObserver._op_updateServer.end(self, _r)

        """
        The updateAdapter operation is called to notify an observer that
        the state of an adapter changed.
        Arguments:
        node -- The node hosting the adapter.
        updatedInfo -- The new adapter state.
        _ctx -- The request context for the invocation.
        """
        def updateAdapter(self, node, updatedInfo, _ctx=None):
            return _M_IceGrid.NodeObserver._op_updateAdapter.invoke(self, ((node, updatedInfo), _ctx))

        """
        The updateAdapter operation is called to notify an observer that
        the state of an adapter changed.
        Arguments:
        node -- The node hosting the adapter.
        updatedInfo -- The new adapter state.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_updateAdapter(self, node, updatedInfo, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.NodeObserver._op_updateAdapter.begin(self, ((node, updatedInfo), _response, _ex, _sent, _ctx))

        """
        The updateAdapter operation is called to notify an observer that
        the state of an adapter changed.
        Arguments:
        node -- The node hosting the adapter.
        updatedInfo -- The new adapter state.
        """
        def end_updateAdapter(self, _r):
            return _M_IceGrid.NodeObserver._op_updateAdapter.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.NodeObserverPrx.ice_checkedCast(proxy, '::IceGrid::NodeObserver', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.NodeObserverPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::NodeObserver'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_NodeObserverPrx = IcePy.defineProxy('::IceGrid::NodeObserver', NodeObserverPrx)

    _M_IceGrid._t_NodeObserver = IcePy.defineClass('::IceGrid::NodeObserver', NodeObserver, -1, (), True, False, None, (), ())
    NodeObserver._ice_type = _M_IceGrid._t_NodeObserver

    NodeObserver._op_nodeInit = IcePy.Operation('nodeInit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_NodeDynamicInfoSeq, False, 0),), (), None, ())
    NodeObserver._op_nodeUp = IcePy.Operation('nodeUp', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_NodeDynamicInfo, False, 0),), (), None, ())
    NodeObserver._op_nodeDown = IcePy.Operation('nodeDown', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0),), (), None, ())
    NodeObserver._op_updateServer = IcePy.Operation('updateServer', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0), ((), _M_IceGrid._t_ServerDynamicInfo, False, 0)), (), None, ())
    NodeObserver._op_updateAdapter = IcePy.Operation('updateAdapter', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0), ((), _M_IceGrid._t_AdapterDynamicInfo, False, 0)), (), None, ())

    _M_IceGrid.NodeObserver = NodeObserver
    del NodeObserver

    _M_IceGrid.NodeObserverPrx = NodeObserverPrx
    del NodeObserverPrx

if 'ApplicationObserver' not in _M_IceGrid.__dict__:
    _M_IceGrid.ApplicationObserver = Ice.createTempClass()
    class ApplicationObserver(Ice.Object):
        """
        The database observer interface. Observers should implement this
        interface to receive information about the state of the IceGrid
        registry database.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.ApplicationObserver:
                raise RuntimeError('IceGrid.ApplicationObserver is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::ApplicationObserver')

        def ice_id(self, current=None):
            return '::IceGrid::ApplicationObserver'

        def ice_staticId():
            return '::IceGrid::ApplicationObserver'
        ice_staticId = staticmethod(ice_staticId)

        def applicationInit(self, serial, applications, current=None):
            """
            applicationInit is called after the registration
            of an observer to indicate the state of the registry.
            Arguments:
            serial -- The current serial number of the registry database. This serial number allows observers to make sure that their internal state is synchronized with the registry.
            applications -- The applications currently registered with the registry.
            current -- The Current object for the invocation.
            """
            pass

        def applicationAdded(self, serial, desc, current=None):
            """
            The applicationAdded operation is called to notify an observer
            that an application was added.
            Arguments:
            serial -- The new serial number of the registry database.
            desc -- The descriptor of the new application.
            current -- The Current object for the invocation.
            """
            pass

        def applicationRemoved(self, serial, name, current=None):
            """
            The applicationRemoved operation is called to notify an observer
            that an application was removed.
            Arguments:
            serial -- The new serial number of the registry database.
            name -- The name of the application that was removed.
            current -- The Current object for the invocation.
            """
            pass

        def applicationUpdated(self, serial, desc, current=None):
            """
            The applicationUpdated operation is called to notify an observer
            that an application was updated.
            Arguments:
            serial -- The new serial number of the registry database.
            desc -- The descriptor of the update.
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_ApplicationObserver)

        __repr__ = __str__

    _M_IceGrid.ApplicationObserverPrx = Ice.createTempClass()
    class ApplicationObserverPrx(Ice.ObjectPrx):

        """
        applicationInit is called after the registration
        of an observer to indicate the state of the registry.
        Arguments:
        serial -- The current serial number of the registry database. This serial number allows observers to make sure that their internal state is synchronized with the registry.
        applications -- The applications currently registered with the registry.
        _ctx -- The request context for the invocation.
        """
        def applicationInit(self, serial, applications, _ctx=None):
            return _M_IceGrid.ApplicationObserver._op_applicationInit.invoke(self, ((serial, applications), _ctx))

        """
        applicationInit is called after the registration
        of an observer to indicate the state of the registry.
        Arguments:
        serial -- The current serial number of the registry database. This serial number allows observers to make sure that their internal state is synchronized with the registry.
        applications -- The applications currently registered with the registry.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applicationInit(self, serial, applications, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.ApplicationObserver._op_applicationInit.begin(self, ((serial, applications), _response, _ex, _sent, _ctx))

        """
        applicationInit is called after the registration
        of an observer to indicate the state of the registry.
        Arguments:
        serial -- The current serial number of the registry database. This serial number allows observers to make sure that their internal state is synchronized with the registry.
        applications -- The applications currently registered with the registry.
        """
        def end_applicationInit(self, _r):
            return _M_IceGrid.ApplicationObserver._op_applicationInit.end(self, _r)

        """
        The applicationAdded operation is called to notify an observer
        that an application was added.
        Arguments:
        serial -- The new serial number of the registry database.
        desc -- The descriptor of the new application.
        _ctx -- The request context for the invocation.
        """
        def applicationAdded(self, serial, desc, _ctx=None):
            return _M_IceGrid.ApplicationObserver._op_applicationAdded.invoke(self, ((serial, desc), _ctx))

        """
        The applicationAdded operation is called to notify an observer
        that an application was added.
        Arguments:
        serial -- The new serial number of the registry database.
        desc -- The descriptor of the new application.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applicationAdded(self, serial, desc, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.ApplicationObserver._op_applicationAdded.begin(self, ((serial, desc), _response, _ex, _sent, _ctx))

        """
        The applicationAdded operation is called to notify an observer
        that an application was added.
        Arguments:
        serial -- The new serial number of the registry database.
        desc -- The descriptor of the new application.
        """
        def end_applicationAdded(self, _r):
            return _M_IceGrid.ApplicationObserver._op_applicationAdded.end(self, _r)

        """
        The applicationRemoved operation is called to notify an observer
        that an application was removed.
        Arguments:
        serial -- The new serial number of the registry database.
        name -- The name of the application that was removed.
        _ctx -- The request context for the invocation.
        """
        def applicationRemoved(self, serial, name, _ctx=None):
            return _M_IceGrid.ApplicationObserver._op_applicationRemoved.invoke(self, ((serial, name), _ctx))

        """
        The applicationRemoved operation is called to notify an observer
        that an application was removed.
        Arguments:
        serial -- The new serial number of the registry database.
        name -- The name of the application that was removed.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applicationRemoved(self, serial, name, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.ApplicationObserver._op_applicationRemoved.begin(self, ((serial, name), _response, _ex, _sent, _ctx))

        """
        The applicationRemoved operation is called to notify an observer
        that an application was removed.
        Arguments:
        serial -- The new serial number of the registry database.
        name -- The name of the application that was removed.
        """
        def end_applicationRemoved(self, _r):
            return _M_IceGrid.ApplicationObserver._op_applicationRemoved.end(self, _r)

        """
        The applicationUpdated operation is called to notify an observer
        that an application was updated.
        Arguments:
        serial -- The new serial number of the registry database.
        desc -- The descriptor of the update.
        _ctx -- The request context for the invocation.
        """
        def applicationUpdated(self, serial, desc, _ctx=None):
            return _M_IceGrid.ApplicationObserver._op_applicationUpdated.invoke(self, ((serial, desc), _ctx))

        """
        The applicationUpdated operation is called to notify an observer
        that an application was updated.
        Arguments:
        serial -- The new serial number of the registry database.
        desc -- The descriptor of the update.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_applicationUpdated(self, serial, desc, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.ApplicationObserver._op_applicationUpdated.begin(self, ((serial, desc), _response, _ex, _sent, _ctx))

        """
        The applicationUpdated operation is called to notify an observer
        that an application was updated.
        Arguments:
        serial -- The new serial number of the registry database.
        desc -- The descriptor of the update.
        """
        def end_applicationUpdated(self, _r):
            return _M_IceGrid.ApplicationObserver._op_applicationUpdated.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.ApplicationObserverPrx.ice_checkedCast(proxy, '::IceGrid::ApplicationObserver', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.ApplicationObserverPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::ApplicationObserver'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_ApplicationObserverPrx = IcePy.defineProxy('::IceGrid::ApplicationObserver', ApplicationObserverPrx)

    _M_IceGrid._t_ApplicationObserver = IcePy.defineClass('::IceGrid::ApplicationObserver', ApplicationObserver, -1, (), True, False, None, (), ())
    ApplicationObserver._ice_type = _M_IceGrid._t_ApplicationObserver

    ApplicationObserver._op_applicationInit = IcePy.Operation('applicationInit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_IceGrid._t_ApplicationInfoSeq, False, 0)), (), None, ())
    ApplicationObserver._op_applicationAdded = IcePy.Operation('applicationAdded', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_IceGrid._t_ApplicationInfo, False, 0)), (), None, ())
    ApplicationObserver._op_applicationRemoved = IcePy.Operation('applicationRemoved', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), IcePy._t_string, False, 0)), (), None, ())
    ApplicationObserver._op_applicationUpdated = IcePy.Operation('applicationUpdated', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_IceGrid._t_ApplicationUpdateInfo, False, 0)), (), None, ())

    _M_IceGrid.ApplicationObserver = ApplicationObserver
    del ApplicationObserver

    _M_IceGrid.ApplicationObserverPrx = ApplicationObserverPrx
    del ApplicationObserverPrx

if 'AdapterObserver' not in _M_IceGrid.__dict__:
    _M_IceGrid.AdapterObserver = Ice.createTempClass()
    class AdapterObserver(Ice.Object):
        """
        This interface allows applications to monitor the state of object
        adapters that are registered with IceGrid.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.AdapterObserver:
                raise RuntimeError('IceGrid.AdapterObserver is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::AdapterObserver')

        def ice_id(self, current=None):
            return '::IceGrid::AdapterObserver'

        def ice_staticId():
            return '::IceGrid::AdapterObserver'
        ice_staticId = staticmethod(ice_staticId)

        def adapterInit(self, adpts, current=None):
            """
            adapterInit is called after registration of
            an observer to indicate the state of the registry.
            Arguments:
            adpts -- The adapters that were dynamically registered with the registry (not through the deployment mechanism).
            current -- The Current object for the invocation.
            """
            pass

        def adapterAdded(self, info, current=None):
            """
            The adapterAdded operation is called to notify an observer when
            a dynamically-registered adapter was added.
            Arguments:
            info -- The details of the new adapter.
            current -- The Current object for the invocation.
            """
            pass

        def adapterUpdated(self, info, current=None):
            """
            The adapterUpdated operation is called to notify an observer when
            a dynamically-registered adapter was updated.
            Arguments:
            info -- The details of the updated adapter.
            current -- The Current object for the invocation.
            """
            pass

        def adapterRemoved(self, id, current=None):
            """
            The adapterRemoved operation is called to notify an observer when
            a dynamically-registered adapter was removed.
            Arguments:
            id -- The ID of the removed adapter.
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_AdapterObserver)

        __repr__ = __str__

    _M_IceGrid.AdapterObserverPrx = Ice.createTempClass()
    class AdapterObserverPrx(Ice.ObjectPrx):

        """
        adapterInit is called after registration of
        an observer to indicate the state of the registry.
        Arguments:
        adpts -- The adapters that were dynamically registered with the registry (not through the deployment mechanism).
        _ctx -- The request context for the invocation.
        """
        def adapterInit(self, adpts, _ctx=None):
            return _M_IceGrid.AdapterObserver._op_adapterInit.invoke(self, ((adpts, ), _ctx))

        """
        adapterInit is called after registration of
        an observer to indicate the state of the registry.
        Arguments:
        adpts -- The adapters that were dynamically registered with the registry (not through the deployment mechanism).
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_adapterInit(self, adpts, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.AdapterObserver._op_adapterInit.begin(self, ((adpts, ), _response, _ex, _sent, _ctx))

        """
        adapterInit is called after registration of
        an observer to indicate the state of the registry.
        Arguments:
        adpts -- The adapters that were dynamically registered with the registry (not through the deployment mechanism).
        """
        def end_adapterInit(self, _r):
            return _M_IceGrid.AdapterObserver._op_adapterInit.end(self, _r)

        """
        The adapterAdded operation is called to notify an observer when
        a dynamically-registered adapter was added.
        Arguments:
        info -- The details of the new adapter.
        _ctx -- The request context for the invocation.
        """
        def adapterAdded(self, info, _ctx=None):
            return _M_IceGrid.AdapterObserver._op_adapterAdded.invoke(self, ((info, ), _ctx))

        """
        The adapterAdded operation is called to notify an observer when
        a dynamically-registered adapter was added.
        Arguments:
        info -- The details of the new adapter.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_adapterAdded(self, info, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.AdapterObserver._op_adapterAdded.begin(self, ((info, ), _response, _ex, _sent, _ctx))

        """
        The adapterAdded operation is called to notify an observer when
        a dynamically-registered adapter was added.
        Arguments:
        info -- The details of the new adapter.
        """
        def end_adapterAdded(self, _r):
            return _M_IceGrid.AdapterObserver._op_adapterAdded.end(self, _r)

        """
        The adapterUpdated operation is called to notify an observer when
        a dynamically-registered adapter was updated.
        Arguments:
        info -- The details of the updated adapter.
        _ctx -- The request context for the invocation.
        """
        def adapterUpdated(self, info, _ctx=None):
            return _M_IceGrid.AdapterObserver._op_adapterUpdated.invoke(self, ((info, ), _ctx))

        """
        The adapterUpdated operation is called to notify an observer when
        a dynamically-registered adapter was updated.
        Arguments:
        info -- The details of the updated adapter.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_adapterUpdated(self, info, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.AdapterObserver._op_adapterUpdated.begin(self, ((info, ), _response, _ex, _sent, _ctx))

        """
        The adapterUpdated operation is called to notify an observer when
        a dynamically-registered adapter was updated.
        Arguments:
        info -- The details of the updated adapter.
        """
        def end_adapterUpdated(self, _r):
            return _M_IceGrid.AdapterObserver._op_adapterUpdated.end(self, _r)

        """
        The adapterRemoved operation is called to notify an observer when
        a dynamically-registered adapter was removed.
        Arguments:
        id -- The ID of the removed adapter.
        _ctx -- The request context for the invocation.
        """
        def adapterRemoved(self, id, _ctx=None):
            return _M_IceGrid.AdapterObserver._op_adapterRemoved.invoke(self, ((id, ), _ctx))

        """
        The adapterRemoved operation is called to notify an observer when
        a dynamically-registered adapter was removed.
        Arguments:
        id -- The ID of the removed adapter.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_adapterRemoved(self, id, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.AdapterObserver._op_adapterRemoved.begin(self, ((id, ), _response, _ex, _sent, _ctx))

        """
        The adapterRemoved operation is called to notify an observer when
        a dynamically-registered adapter was removed.
        Arguments:
        id -- The ID of the removed adapter.
        """
        def end_adapterRemoved(self, _r):
            return _M_IceGrid.AdapterObserver._op_adapterRemoved.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.AdapterObserverPrx.ice_checkedCast(proxy, '::IceGrid::AdapterObserver', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.AdapterObserverPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::AdapterObserver'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_AdapterObserverPrx = IcePy.defineProxy('::IceGrid::AdapterObserver', AdapterObserverPrx)

    _M_IceGrid._t_AdapterObserver = IcePy.defineClass('::IceGrid::AdapterObserver', AdapterObserver, -1, (), True, False, None, (), ())
    AdapterObserver._ice_type = _M_IceGrid._t_AdapterObserver

    AdapterObserver._op_adapterInit = IcePy.Operation('adapterInit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_AdapterInfoSeq, False, 0),), (), None, ())
    AdapterObserver._op_adapterAdded = IcePy.Operation('adapterAdded', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_AdapterInfo, False, 0),), (), None, ())
    AdapterObserver._op_adapterUpdated = IcePy.Operation('adapterUpdated', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_AdapterInfo, False, 0),), (), None, ())
    AdapterObserver._op_adapterRemoved = IcePy.Operation('adapterRemoved', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0),), (), None, ())

    _M_IceGrid.AdapterObserver = AdapterObserver
    del AdapterObserver

    _M_IceGrid.AdapterObserverPrx = AdapterObserverPrx
    del AdapterObserverPrx

if 'ObjectObserver' not in _M_IceGrid.__dict__:
    _M_IceGrid.ObjectObserver = Ice.createTempClass()
    class ObjectObserver(Ice.Object):
        """
        This interface allows applications to monitor IceGrid well-known objects.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.ObjectObserver:
                raise RuntimeError('IceGrid.ObjectObserver is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::ObjectObserver')

        def ice_id(self, current=None):
            return '::IceGrid::ObjectObserver'

        def ice_staticId():
            return '::IceGrid::ObjectObserver'
        ice_staticId = staticmethod(ice_staticId)

        def objectInit(self, objects, current=None):
            """
            objectInit is called after the registration of
            an observer to indicate the state of the registry.
            Arguments:
            objects -- The objects registered with the Admin interface (not through the deployment mechanism).
            current -- The Current object for the invocation.
            """
            pass

        def objectAdded(self, info, current=None):
            """
            The objectAdded operation is called to notify an observer when an
            object was added to the Admin interface.
            Arguments:
            info -- The details of the added object.
            current -- The Current object for the invocation.
            """
            pass

        def objectUpdated(self, info, current=None):
            """
            objectUpdated is called to notify an observer when
            an object registered with the Admin interface was updated.
            Arguments:
            info -- The details of the updated object.
            current -- The Current object for the invocation.
            """
            pass

        def objectRemoved(self, id, current=None):
            """
            objectRemoved is called to notify an observer when
            an object registered with the Admin interface was removed.
            Arguments:
            id -- The identity of the removed object.
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_ObjectObserver)

        __repr__ = __str__

    _M_IceGrid.ObjectObserverPrx = Ice.createTempClass()
    class ObjectObserverPrx(Ice.ObjectPrx):

        """
        objectInit is called after the registration of
        an observer to indicate the state of the registry.
        Arguments:
        objects -- The objects registered with the Admin interface (not through the deployment mechanism).
        _ctx -- The request context for the invocation.
        """
        def objectInit(self, objects, _ctx=None):
            return _M_IceGrid.ObjectObserver._op_objectInit.invoke(self, ((objects, ), _ctx))

        """
        objectInit is called after the registration of
        an observer to indicate the state of the registry.
        Arguments:
        objects -- The objects registered with the Admin interface (not through the deployment mechanism).
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_objectInit(self, objects, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.ObjectObserver._op_objectInit.begin(self, ((objects, ), _response, _ex, _sent, _ctx))

        """
        objectInit is called after the registration of
        an observer to indicate the state of the registry.
        Arguments:
        objects -- The objects registered with the Admin interface (not through the deployment mechanism).
        """
        def end_objectInit(self, _r):
            return _M_IceGrid.ObjectObserver._op_objectInit.end(self, _r)

        """
        The objectAdded operation is called to notify an observer when an
        object was added to the Admin interface.
        Arguments:
        info -- The details of the added object.
        _ctx -- The request context for the invocation.
        """
        def objectAdded(self, info, _ctx=None):
            return _M_IceGrid.ObjectObserver._op_objectAdded.invoke(self, ((info, ), _ctx))

        """
        The objectAdded operation is called to notify an observer when an
        object was added to the Admin interface.
        Arguments:
        info -- The details of the added object.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_objectAdded(self, info, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.ObjectObserver._op_objectAdded.begin(self, ((info, ), _response, _ex, _sent, _ctx))

        """
        The objectAdded operation is called to notify an observer when an
        object was added to the Admin interface.
        Arguments:
        info -- The details of the added object.
        """
        def end_objectAdded(self, _r):
            return _M_IceGrid.ObjectObserver._op_objectAdded.end(self, _r)

        """
        objectUpdated is called to notify an observer when
        an object registered with the Admin interface was updated.
        Arguments:
        info -- The details of the updated object.
        _ctx -- The request context for the invocation.
        """
        def objectUpdated(self, info, _ctx=None):
            return _M_IceGrid.ObjectObserver._op_objectUpdated.invoke(self, ((info, ), _ctx))

        """
        objectUpdated is called to notify an observer when
        an object registered with the Admin interface was updated.
        Arguments:
        info -- The details of the updated object.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_objectUpdated(self, info, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.ObjectObserver._op_objectUpdated.begin(self, ((info, ), _response, _ex, _sent, _ctx))

        """
        objectUpdated is called to notify an observer when
        an object registered with the Admin interface was updated.
        Arguments:
        info -- The details of the updated object.
        """
        def end_objectUpdated(self, _r):
            return _M_IceGrid.ObjectObserver._op_objectUpdated.end(self, _r)

        """
        objectRemoved is called to notify an observer when
        an object registered with the Admin interface was removed.
        Arguments:
        id -- The identity of the removed object.
        _ctx -- The request context for the invocation.
        """
        def objectRemoved(self, id, _ctx=None):
            return _M_IceGrid.ObjectObserver._op_objectRemoved.invoke(self, ((id, ), _ctx))

        """
        objectRemoved is called to notify an observer when
        an object registered with the Admin interface was removed.
        Arguments:
        id -- The identity of the removed object.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_objectRemoved(self, id, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.ObjectObserver._op_objectRemoved.begin(self, ((id, ), _response, _ex, _sent, _ctx))

        """
        objectRemoved is called to notify an observer when
        an object registered with the Admin interface was removed.
        Arguments:
        id -- The identity of the removed object.
        """
        def end_objectRemoved(self, _r):
            return _M_IceGrid.ObjectObserver._op_objectRemoved.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.ObjectObserverPrx.ice_checkedCast(proxy, '::IceGrid::ObjectObserver', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.ObjectObserverPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::ObjectObserver'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_ObjectObserverPrx = IcePy.defineProxy('::IceGrid::ObjectObserver', ObjectObserverPrx)

    _M_IceGrid._t_ObjectObserver = IcePy.defineClass('::IceGrid::ObjectObserver', ObjectObserver, -1, (), True, False, None, (), ())
    ObjectObserver._ice_type = _M_IceGrid._t_ObjectObserver

    ObjectObserver._op_objectInit = IcePy.Operation('objectInit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_ObjectInfoSeq, False, 0),), (), None, ())
    ObjectObserver._op_objectAdded = IcePy.Operation('objectAdded', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_ObjectInfo, False, 0),), (), None, ())
    ObjectObserver._op_objectUpdated = IcePy.Operation('objectUpdated', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_ObjectInfo, False, 0),), (), None, ())
    ObjectObserver._op_objectRemoved = IcePy.Operation('objectRemoved', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_Ice._t_Identity, False, 0),), (), None, ())

    _M_IceGrid.ObjectObserver = ObjectObserver
    del ObjectObserver

    _M_IceGrid.ObjectObserverPrx = ObjectObserverPrx
    del ObjectObserverPrx

if 'RegistryObserver' not in _M_IceGrid.__dict__:
    _M_IceGrid.RegistryObserver = Ice.createTempClass()
    class RegistryObserver(Ice.Object):
        """
        This interface allows applications to monitor changes the state
        of the registry.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.RegistryObserver:
                raise RuntimeError('IceGrid.RegistryObserver is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::RegistryObserver')

        def ice_id(self, current=None):
            return '::IceGrid::RegistryObserver'

        def ice_staticId():
            return '::IceGrid::RegistryObserver'
        ice_staticId = staticmethod(ice_staticId)

        def registryInit(self, registries, current=None):
            """
            The registryInit operation is called after registration of
            an observer to indicate the state of the registries.
            Arguments:
            registries -- The current state of the registries.
            current -- The Current object for the invocation.
            """
            pass

        def registryUp(self, node, current=None):
            """
            The nodeUp operation is called to notify an observer that a node
            came up.
            Arguments:
            node -- The node state.
            current -- The Current object for the invocation.
            """
            pass

        def registryDown(self, name, current=None):
            """
            The nodeDown operation is called to notify an observer that a node
            went down.
            Arguments:
            name -- The node name.
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_RegistryObserver)

        __repr__ = __str__

    _M_IceGrid.RegistryObserverPrx = Ice.createTempClass()
    class RegistryObserverPrx(Ice.ObjectPrx):

        """
        The registryInit operation is called after registration of
        an observer to indicate the state of the registries.
        Arguments:
        registries -- The current state of the registries.
        _ctx -- The request context for the invocation.
        """
        def registryInit(self, registries, _ctx=None):
            return _M_IceGrid.RegistryObserver._op_registryInit.invoke(self, ((registries, ), _ctx))

        """
        The registryInit operation is called after registration of
        an observer to indicate the state of the registries.
        Arguments:
        registries -- The current state of the registries.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_registryInit(self, registries, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.RegistryObserver._op_registryInit.begin(self, ((registries, ), _response, _ex, _sent, _ctx))

        """
        The registryInit operation is called after registration of
        an observer to indicate the state of the registries.
        Arguments:
        registries -- The current state of the registries.
        """
        def end_registryInit(self, _r):
            return _M_IceGrid.RegistryObserver._op_registryInit.end(self, _r)

        """
        The nodeUp operation is called to notify an observer that a node
        came up.
        Arguments:
        node -- The node state.
        _ctx -- The request context for the invocation.
        """
        def registryUp(self, node, _ctx=None):
            return _M_IceGrid.RegistryObserver._op_registryUp.invoke(self, ((node, ), _ctx))

        """
        The nodeUp operation is called to notify an observer that a node
        came up.
        Arguments:
        node -- The node state.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_registryUp(self, node, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.RegistryObserver._op_registryUp.begin(self, ((node, ), _response, _ex, _sent, _ctx))

        """
        The nodeUp operation is called to notify an observer that a node
        came up.
        Arguments:
        node -- The node state.
        """
        def end_registryUp(self, _r):
            return _M_IceGrid.RegistryObserver._op_registryUp.end(self, _r)

        """
        The nodeDown operation is called to notify an observer that a node
        went down.
        Arguments:
        name -- The node name.
        _ctx -- The request context for the invocation.
        """
        def registryDown(self, name, _ctx=None):
            return _M_IceGrid.RegistryObserver._op_registryDown.invoke(self, ((name, ), _ctx))

        """
        The nodeDown operation is called to notify an observer that a node
        went down.
        Arguments:
        name -- The node name.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_registryDown(self, name, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.RegistryObserver._op_registryDown.begin(self, ((name, ), _response, _ex, _sent, _ctx))

        """
        The nodeDown operation is called to notify an observer that a node
        went down.
        Arguments:
        name -- The node name.
        """
        def end_registryDown(self, _r):
            return _M_IceGrid.RegistryObserver._op_registryDown.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.RegistryObserverPrx.ice_checkedCast(proxy, '::IceGrid::RegistryObserver', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.RegistryObserverPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::RegistryObserver'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_RegistryObserverPrx = IcePy.defineProxy('::IceGrid::RegistryObserver', RegistryObserverPrx)

    _M_IceGrid._t_RegistryObserver = IcePy.defineClass('::IceGrid::RegistryObserver', RegistryObserver, -1, (), True, False, None, (), ())
    RegistryObserver._ice_type = _M_IceGrid._t_RegistryObserver

    RegistryObserver._op_registryInit = IcePy.Operation('registryInit', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_RegistryInfoSeq, False, 0),), (), None, ())
    RegistryObserver._op_registryUp = IcePy.Operation('registryUp', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_IceGrid._t_RegistryInfo, False, 0),), (), None, ())
    RegistryObserver._op_registryDown = IcePy.Operation('registryDown', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0),), (), None, ())

    _M_IceGrid.RegistryObserver = RegistryObserver
    del RegistryObserver

    _M_IceGrid.RegistryObserverPrx = RegistryObserverPrx
    del RegistryObserverPrx

# End of module IceGrid

Ice.sliceChecksums["::IceGrid::AdapterDynamicInfo"] = "b371e9a58f115e6ebfbcda735fee57f7"
Ice.sliceChecksums["::IceGrid::AdapterDynamicInfoSeq"] = "54465843167a2f93fa96d13b7f41ea32"
Ice.sliceChecksums["::IceGrid::AdapterObserver"] = "7f4ed59e236da9d6c35ad7e6ad9cb0"
Ice.sliceChecksums["::IceGrid::ApplicationObserver"] = "2862cdcba54714282f68b13a8fb4ae"
Ice.sliceChecksums["::IceGrid::NodeDynamicInfo"] = "3ad52341f32973212d26a9a6dda08b"
Ice.sliceChecksums["::IceGrid::NodeDynamicInfoSeq"] = "f61633c5e3992f718dba78b7f165c2"
Ice.sliceChecksums["::IceGrid::NodeObserver"] = "e06c1ad6807d2876de9e818855a65738"
Ice.sliceChecksums["::IceGrid::ObjectObserver"] = "5364683a872f127e46cc5e215d98c3c"
Ice.sliceChecksums["::IceGrid::RegistryObserver"] = "fd83b1558e7c77f2d322b25449518"
Ice.sliceChecksums["::IceGrid::ServerDynamicInfo"] = "fd4b9177ca54ae4688b51fa51d6870"
Ice.sliceChecksums["::IceGrid::ServerDynamicInfoSeq"] = "e3fda58997d5cd946e78cae739174cb"



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `PermissionsVerifier.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Glacier2_SSLInfo_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Start of module Glacier2
__name__ = 'Glacier2'

if 'PermissionDeniedException' not in _M_Glacier2.__dict__:
    _M_Glacier2.PermissionDeniedException = Ice.createTempClass()
    class PermissionDeniedException(Ice.UserException):
        """
        This exception is raised if a client is denied the ability to create
        a session with the router.
        Members:
        reason -- The reason why permission was denied.
        """
        def __init__(self, reason=''):
            self.reason = reason

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'Glacier2::PermissionDeniedException'

    _M_Glacier2._t_PermissionDeniedException = IcePy.defineException('::Glacier2::PermissionDeniedException', PermissionDeniedException, (), True, None, (('reason', (), IcePy._t_string, False, 0),))
    PermissionDeniedException._ice_type = _M_Glacier2._t_PermissionDeniedException

    _M_Glacier2.PermissionDeniedException = PermissionDeniedException
    del PermissionDeniedException

if 'PermissionsVerifier' not in _M_Glacier2.__dict__:
    _M_Glacier2.PermissionsVerifier = Ice.createTempClass()
    class PermissionsVerifier(Ice.Object):
        """
        The Glacier2 permissions verifier. This is called through the
        process of establishing a session.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.PermissionsVerifier:
                raise RuntimeError('Glacier2.PermissionsVerifier is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::PermissionsVerifier', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Glacier2::PermissionsVerifier'

        def ice_staticId():
            return '::Glacier2::PermissionsVerifier'
        ice_staticId = staticmethod(ice_staticId)

        def checkPermissions(self, userId, password, current=None):
            """
            Check whether a user has permission to access the router.
            Arguments:
            userId -- The user id for which to check permission.
            password -- The user's password.
            current -- The Current object for the invocation.
            Returns a tuple containing the following:
            _retval -- True if access is granted, or false otherwise.
            reason -- The reason why access was denied.
            Throws:
            PermissionDeniedException -- Raised if the user access is denied. This can be raised in place of returning false with a reason set in the reason out parameter.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_PermissionsVerifier)

        __repr__ = __str__

    _M_Glacier2.PermissionsVerifierPrx = Ice.createTempClass()
    class PermissionsVerifierPrx(Ice.ObjectPrx):

        """
        Check whether a user has permission to access the router.
        Arguments:
        userId -- The user id for which to check permission.
        password -- The user's password.
        _ctx -- The request context for the invocation.
        Returns a tuple containing the following:
        _retval -- True if access is granted, or false otherwise.
        reason -- The reason why access was denied.
        Throws:
        PermissionDeniedException -- Raised if the user access is denied. This can be raised in place of returning false with a reason set in the reason out parameter.
        """
        def checkPermissions(self, userId, password, _ctx=None):
            return _M_Glacier2.PermissionsVerifier._op_checkPermissions.invoke(self, ((userId, password), _ctx))

        """
        Check whether a user has permission to access the router.
        Arguments:
        userId -- The user id for which to check permission.
        password -- The user's password.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_checkPermissions(self, userId, password, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.PermissionsVerifier._op_checkPermissions.begin(self, ((userId, password), _response, _ex, _sent, _ctx))

        """
        Check whether a user has permission to access the router.
        Arguments:
        userId -- The user id for which to check permission.
        password -- The user's password.
        Returns a tuple containing the following:
        _retval -- True if access is granted, or false otherwise.
        reason -- The reason why access was denied.
        Throws:
        PermissionDeniedException -- Raised if the user access is denied. This can be raised in place of returning false with a reason set in the reason out parameter.
        """
        def end_checkPermissions(self, _r):
            return _M_Glacier2.PermissionsVerifier._op_checkPermissions.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.PermissionsVerifierPrx.ice_checkedCast(proxy, '::Glacier2::PermissionsVerifier', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.PermissionsVerifierPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::PermissionsVerifier'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_PermissionsVerifierPrx = IcePy.defineProxy('::Glacier2::PermissionsVerifier', PermissionsVerifierPrx)

    _M_Glacier2._t_PermissionsVerifier = IcePy.defineClass('::Glacier2::PermissionsVerifier', PermissionsVerifier, -1, (), True, False, None, (), ())
    PermissionsVerifier._ice_type = _M_Glacier2._t_PermissionsVerifier

    PermissionsVerifier._op_checkPermissions = IcePy.Operation('checkPermissions', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, Ice.FormatType.SlicedFormat, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (((), IcePy._t_string, False, 0),), ((), IcePy._t_bool, False, 0), (_M_Glacier2._t_PermissionDeniedException,))

    _M_Glacier2.PermissionsVerifier = PermissionsVerifier
    del PermissionsVerifier

    _M_Glacier2.PermissionsVerifierPrx = PermissionsVerifierPrx
    del PermissionsVerifierPrx

if 'SSLPermissionsVerifier' not in _M_Glacier2.__dict__:
    _M_Glacier2.SSLPermissionsVerifier = Ice.createTempClass()
    class SSLPermissionsVerifier(Ice.Object):
        """
        The SSL Glacier2 permissions verifier. This is called through the
        process of establishing a session.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.SSLPermissionsVerifier:
                raise RuntimeError('Glacier2.SSLPermissionsVerifier is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::SSLPermissionsVerifier', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Glacier2::SSLPermissionsVerifier'

        def ice_staticId():
            return '::Glacier2::SSLPermissionsVerifier'
        ice_staticId = staticmethod(ice_staticId)

        def authorize(self, info, current=None):
            """
            Check whether a user has permission to access the router.
            Arguments:
            info -- The SSL information.
            current -- The Current object for the invocation.
            Returns a tuple containing the following:
            _retval -- True if access is granted, or false otherwise.
            reason -- The reason why access was denied.
            Throws:
            PermissionDeniedException -- Raised if the user access is denied. This can be raised in place of returning false with a reason set in the reason out parameter.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_SSLPermissionsVerifier)

        __repr__ = __str__

    _M_Glacier2.SSLPermissionsVerifierPrx = Ice.createTempClass()
    class SSLPermissionsVerifierPrx(Ice.ObjectPrx):

        """
        Check whether a user has permission to access the router.
        Arguments:
        info -- The SSL information.
        _ctx -- The request context for the invocation.
        Returns a tuple containing the following:
        _retval -- True if access is granted, or false otherwise.
        reason -- The reason why access was denied.
        Throws:
        PermissionDeniedException -- Raised if the user access is denied. This can be raised in place of returning false with a reason set in the reason out parameter.
        """
        def authorize(self, info, _ctx=None):
            return _M_Glacier2.SSLPermissionsVerifier._op_authorize.invoke(self, ((info, ), _ctx))

        """
        Check whether a user has permission to access the router.
        Arguments:
        info -- The SSL information.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_authorize(self, info, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.SSLPermissionsVerifier._op_authorize.begin(self, ((info, ), _response, _ex, _sent, _ctx))

        """
        Check whether a user has permission to access the router.
        Arguments:
        info -- The SSL information.
        Returns a tuple containing the following:
        _retval -- True if access is granted, or false otherwise.
        reason -- The reason why access was denied.
        Throws:
        PermissionDeniedException -- Raised if the user access is denied. This can be raised in place of returning false with a reason set in the reason out parameter.
        """
        def end_authorize(self, _r):
            return _M_Glacier2.SSLPermissionsVerifier._op_authorize.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.SSLPermissionsVerifierPrx.ice_checkedCast(proxy, '::Glacier2::SSLPermissionsVerifier', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.SSLPermissionsVerifierPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::SSLPermissionsVerifier'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_SSLPermissionsVerifierPrx = IcePy.defineProxy('::Glacier2::SSLPermissionsVerifier', SSLPermissionsVerifierPrx)

    _M_Glacier2._t_SSLPermissionsVerifier = IcePy.defineClass('::Glacier2::SSLPermissionsVerifier', SSLPermissionsVerifier, -1, (), True, False, None, (), ())
    SSLPermissionsVerifier._ice_type = _M_Glacier2._t_SSLPermissionsVerifier

    SSLPermissionsVerifier._op_authorize = IcePy.Operation('authorize', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, Ice.FormatType.SlicedFormat, (), (((), _M_Glacier2._t_SSLInfo, False, 0),), (((), IcePy._t_string, False, 0),), ((), IcePy._t_bool, False, 0), (_M_Glacier2._t_PermissionDeniedException,))

    _M_Glacier2.SSLPermissionsVerifier = SSLPermissionsVerifier
    del SSLPermissionsVerifier

    _M_Glacier2.SSLPermissionsVerifierPrx = SSLPermissionsVerifierPrx
    del SSLPermissionsVerifierPrx

# End of module Glacier2

Ice.sliceChecksums["::Glacier2::PermissionDeniedException"] = "27def8d4569ab203b629b9162d530ba"
Ice.sliceChecksums["::Glacier2::PermissionsVerifier"] = "fcf33ee75c6e0e651d33c88bbca148d"
Ice.sliceChecksums["::Glacier2::SSLPermissionsVerifier"] = "c9d5a5d4c26aae9cb2da81d56f9f9e1"



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Router.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_Router_ice
import Glacier2_Session_ice
import Glacier2_PermissionsVerifier_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Start of module Glacier2
__name__ = 'Glacier2'
_M_Glacier2.__doc__ = """
Glacier2 is a firewall solution for Ice. Glacier2 authenticates
and filters client requests and allows callbacks to the client in a
secure fashion. In combination with IceSSL, Glacier2 provides a
security solution that is both non-intrusive and easy to configure.
"""

if 'SessionNotExistException' not in _M_Glacier2.__dict__:
    _M_Glacier2.SessionNotExistException = Ice.createTempClass()
    class SessionNotExistException(Ice.UserException):
        """
        This exception is raised if a client tries to destroy a session
        with a router, but no session exists for the client.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'Glacier2::SessionNotExistException'

    _M_Glacier2._t_SessionNotExistException = IcePy.defineException('::Glacier2::SessionNotExistException', SessionNotExistException, (), False, None, ())
    SessionNotExistException._ice_type = _M_Glacier2._t_SessionNotExistException

    _M_Glacier2.SessionNotExistException = SessionNotExistException
    del SessionNotExistException

if 'Router' not in _M_Glacier2.__dict__:
    _M_Glacier2.Router = Ice.createTempClass()
    class Router(_M_Ice.Router):
        """
        The Glacier2 specialization of the Ice.Router
        interface.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.Router:
                raise RuntimeError('Glacier2.Router is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::Router', '::Ice::Object', '::Ice::Router')

        def ice_id(self, current=None):
            return '::Glacier2::Router'

        def ice_staticId():
            return '::Glacier2::Router'
        ice_staticId = staticmethod(ice_staticId)

        def getCategoryForClient(self, current=None):
            """
            This category must be used in the identities of all of the client's
            callback objects. This is necessary in order for the router to
            forward callback requests to the intended client. If the Glacier2
            server endpoints are not set, the returned category is an empty
            string.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The category.
            """
            pass

        def createSession_async(self, _cb, userId, password, current=None):
            """
            Create a per-client session with the router. If a
            SessionManager has been installed, a proxy to a Session
            object is returned to the client. Otherwise, null is returned
            and only an internal session (i.e., not visible to the client)
            is created.
            If a session proxy is returned, it must be configured to route
            through the router that created it. This will happen automatically
            if the router is configured as the client's default router at the
            time the session proxy is created in the client process, otherwise
            the client must configure the session proxy explicitly.
            Arguments:
            _cb -- The asynchronous callback object.
            userId -- The user id for which to check the password.
            password -- The password for the given user id.
            current -- The Current object for the invocation.
            Throws:
            CannotCreateSessionException -- Raised if the session cannot be created.
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            pass

        def createSessionFromSecureConnection_async(self, _cb, current=None):
            """
            Create a per-client session with the router. The user is
            authenticated through the SSL certificates that have been
            associated with the connection. If a SessionManager has been
            installed, a proxy to a Session object is returned to the
            client. Otherwise, null is returned and only an internal
            session (i.e., not visible to the client) is created.
            If a session proxy is returned, it must be configured to route
            through the router that created it. This will happen automatically
            if the router is configured as the client's default router at the
            time the session proxy is created in the client process, otherwise
            the client must configure the session proxy explicitly.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            Throws:
            CannotCreateSessionException -- Raised if the session cannot be created.
            PermissionDeniedException -- Raised if the user cannot be authenticated or if the user is not allowed access.
            """
            pass

        def refreshSession_async(self, _cb, current=None):
            """
            Keep the calling client's session with this router alive.
            Arguments:
            _cb -- The asynchronous callback object.
            current -- The Current object for the invocation.
            Throws:
            SessionNotExistException -- Raised if no session exists for the calling client.
            """
            pass

        def destroySession(self, current=None):
            """
            Destroy the calling client's session with this router.
            Arguments:
            current -- The Current object for the invocation.
            Throws:
            SessionNotExistException -- Raised if no session exists for the calling client.
            """
            pass

        def getSessionTimeout(self, current=None):
            """
            Get the value of the session timeout. Sessions are destroyed
            if they see no activity for this period of time.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The timeout (in seconds).
            """
            pass

        def getACMTimeout(self, current=None):
            """
            Get the value of the ACM timeout. Clients supporting connection
            heartbeats can enable them instead of explicitly sending keep
            alives requests.
            NOTE: This method is only available since Ice 3.6.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The timeout (in seconds).
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_Router)

        __repr__ = __str__

    _M_Glacier2.RouterPrx = Ice.createTempClass()
    class RouterPrx(_M_Ice.RouterPrx):

        """
        This category must be used in the identities of all of the client's
        callback objects. This is necessary in order for the router to
        forward callback requests to the intended client. If the Glacier2
        server endpoints are not set, the returned category is an empty
        string.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The category.
        """
        def getCategoryForClient(self, _ctx=None):
            return _M_Glacier2.Router._op_getCategoryForClient.invoke(self, ((), _ctx))

        """
        This category must be used in the identities of all of the client's
        callback objects. This is necessary in order for the router to
        forward callback requests to the intended client. If the Glacier2
        server endpoints are not set, the returned category is an empty
        string.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getCategoryForClient(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.Router._op_getCategoryForClient.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        This category must be used in the identities of all of the client's
        callback objects. This is necessary in order for the router to
        forward callback requests to the intended client. If the Glacier2
        server endpoints are not set, the returned category is an empty
        string.
        Arguments:
        Returns: The category.
        """
        def end_getCategoryForClient(self, _r):
            return _M_Glacier2.Router._op_getCategoryForClient.end(self, _r)

        """
        Create a per-client session with the router. If a
        SessionManager has been installed, a proxy to a Session
        object is returned to the client. Otherwise, null is returned
        and only an internal session (i.e., not visible to the client)
        is created.
        If a session proxy is returned, it must be configured to route
        through the router that created it. This will happen automatically
        if the router is configured as the client's default router at the
        time the session proxy is created in the client process, otherwise
        the client must configure the session proxy explicitly.
        Arguments:
        userId -- The user id for which to check the password.
        password -- The password for the given user id.
        _ctx -- The request context for the invocation.
        Returns: A proxy for the newly created session, or null if no SessionManager has been installed.
        Throws:
        CannotCreateSessionException -- Raised if the session cannot be created.
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createSession(self, userId, password, _ctx=None):
            return _M_Glacier2.Router._op_createSession.invoke(self, ((userId, password), _ctx))

        """
        Create a per-client session with the router. If a
        SessionManager has been installed, a proxy to a Session
        object is returned to the client. Otherwise, null is returned
        and only an internal session (i.e., not visible to the client)
        is created.
        If a session proxy is returned, it must be configured to route
        through the router that created it. This will happen automatically
        if the router is configured as the client's default router at the
        time the session proxy is created in the client process, otherwise
        the client must configure the session proxy explicitly.
        Arguments:
        userId -- The user id for which to check the password.
        password -- The password for the given user id.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSession(self, userId, password, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.Router._op_createSession.begin(self, ((userId, password), _response, _ex, _sent, _ctx))

        """
        Create a per-client session with the router. If a
        SessionManager has been installed, a proxy to a Session
        object is returned to the client. Otherwise, null is returned
        and only an internal session (i.e., not visible to the client)
        is created.
        If a session proxy is returned, it must be configured to route
        through the router that created it. This will happen automatically
        if the router is configured as the client's default router at the
        time the session proxy is created in the client process, otherwise
        the client must configure the session proxy explicitly.
        Arguments:
        userId -- The user id for which to check the password.
        password -- The password for the given user id.
        Returns: A proxy for the newly created session, or null if no SessionManager has been installed.
        Throws:
        CannotCreateSessionException -- Raised if the session cannot be created.
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createSession(self, _r):
            return _M_Glacier2.Router._op_createSession.end(self, _r)

        """
        Create a per-client session with the router. The user is
        authenticated through the SSL certificates that have been
        associated with the connection. If a SessionManager has been
        installed, a proxy to a Session object is returned to the
        client. Otherwise, null is returned and only an internal
        session (i.e., not visible to the client) is created.
        If a session proxy is returned, it must be configured to route
        through the router that created it. This will happen automatically
        if the router is configured as the client's default router at the
        time the session proxy is created in the client process, otherwise
        the client must configure the session proxy explicitly.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: A proxy for the newly created session, or null if no SessionManager has been installed.
        Throws:
        CannotCreateSessionException -- Raised if the session cannot be created.
        PermissionDeniedException -- Raised if the user cannot be authenticated or if the user is not allowed access.
        """
        def createSessionFromSecureConnection(self, _ctx=None):
            return _M_Glacier2.Router._op_createSessionFromSecureConnection.invoke(self, ((), _ctx))

        """
        Create a per-client session with the router. The user is
        authenticated through the SSL certificates that have been
        associated with the connection. If a SessionManager has been
        installed, a proxy to a Session object is returned to the
        client. Otherwise, null is returned and only an internal
        session (i.e., not visible to the client) is created.
        If a session proxy is returned, it must be configured to route
        through the router that created it. This will happen automatically
        if the router is configured as the client's default router at the
        time the session proxy is created in the client process, otherwise
        the client must configure the session proxy explicitly.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSessionFromSecureConnection(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.Router._op_createSessionFromSecureConnection.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Create a per-client session with the router. The user is
        authenticated through the SSL certificates that have been
        associated with the connection. If a SessionManager has been
        installed, a proxy to a Session object is returned to the
        client. Otherwise, null is returned and only an internal
        session (i.e., not visible to the client) is created.
        If a session proxy is returned, it must be configured to route
        through the router that created it. This will happen automatically
        if the router is configured as the client's default router at the
        time the session proxy is created in the client process, otherwise
        the client must configure the session proxy explicitly.
        Arguments:
        Returns: A proxy for the newly created session, or null if no SessionManager has been installed.
        Throws:
        CannotCreateSessionException -- Raised if the session cannot be created.
        PermissionDeniedException -- Raised if the user cannot be authenticated or if the user is not allowed access.
        """
        def end_createSessionFromSecureConnection(self, _r):
            return _M_Glacier2.Router._op_createSessionFromSecureConnection.end(self, _r)

        """
        Keep the calling client's session with this router alive.
        Arguments:
        _ctx -- The request context for the invocation.
        Throws:
        SessionNotExistException -- Raised if no session exists for the calling client.
        """
        def refreshSession(self, _ctx=None):
            return _M_Glacier2.Router._op_refreshSession.invoke(self, ((), _ctx))

        """
        Keep the calling client's session with this router alive.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_refreshSession(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.Router._op_refreshSession.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Keep the calling client's session with this router alive.
        Arguments:
        Throws:
        SessionNotExistException -- Raised if no session exists for the calling client.
        """
        def end_refreshSession(self, _r):
            return _M_Glacier2.Router._op_refreshSession.end(self, _r)

        """
        Destroy the calling client's session with this router.
        Arguments:
        _ctx -- The request context for the invocation.
        Throws:
        SessionNotExistException -- Raised if no session exists for the calling client.
        """
        def destroySession(self, _ctx=None):
            return _M_Glacier2.Router._op_destroySession.invoke(self, ((), _ctx))

        """
        Destroy the calling client's session with this router.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_destroySession(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.Router._op_destroySession.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Destroy the calling client's session with this router.
        Arguments:
        Throws:
        SessionNotExistException -- Raised if no session exists for the calling client.
        """
        def end_destroySession(self, _r):
            return _M_Glacier2.Router._op_destroySession.end(self, _r)

        """
        Get the value of the session timeout. Sessions are destroyed
        if they see no activity for this period of time.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The timeout (in seconds).
        """
        def getSessionTimeout(self, _ctx=None):
            return _M_Glacier2.Router._op_getSessionTimeout.invoke(self, ((), _ctx))

        """
        Get the value of the session timeout. Sessions are destroyed
        if they see no activity for this period of time.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getSessionTimeout(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.Router._op_getSessionTimeout.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the value of the session timeout. Sessions are destroyed
        if they see no activity for this period of time.
        Arguments:
        Returns: The timeout (in seconds).
        """
        def end_getSessionTimeout(self, _r):
            return _M_Glacier2.Router._op_getSessionTimeout.end(self, _r)

        """
        Get the value of the ACM timeout. Clients supporting connection
        heartbeats can enable them instead of explicitly sending keep
        alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The timeout (in seconds).
        """
        def getACMTimeout(self, _ctx=None):
            return _M_Glacier2.Router._op_getACMTimeout.invoke(self, ((), _ctx))

        """
        Get the value of the ACM timeout. Clients supporting connection
        heartbeats can enable them instead of explicitly sending keep
        alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getACMTimeout(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.Router._op_getACMTimeout.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the value of the ACM timeout. Clients supporting connection
        heartbeats can enable them instead of explicitly sending keep
        alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        Returns: The timeout (in seconds).
        """
        def end_getACMTimeout(self, _r):
            return _M_Glacier2.Router._op_getACMTimeout.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.RouterPrx.ice_checkedCast(proxy, '::Glacier2::Router', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.RouterPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::Router'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_RouterPrx = IcePy.defineProxy('::Glacier2::Router', RouterPrx)

    _M_Glacier2._t_Router = IcePy.defineClass('::Glacier2::Router', Router, -1, (), True, False, None, (_M_Ice._t_Router,), ())
    Router._ice_type = _M_Glacier2._t_Router

    Router._op_getCategoryForClient = IcePy.Operation('getCategoryForClient', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_string, False, 0), ())
    Router._op_createSession = IcePy.Operation('createSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, Ice.FormatType.SlicedFormat, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_Glacier2._t_SessionPrx, False, 0), (_M_Glacier2._t_PermissionDeniedException, _M_Glacier2._t_CannotCreateSessionException))
    Router._op_createSessionFromSecureConnection = IcePy.Operation('createSessionFromSecureConnection', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, Ice.FormatType.SlicedFormat, (), (), (), ((), _M_Glacier2._t_SessionPrx, False, 0), (_M_Glacier2._t_PermissionDeniedException, _M_Glacier2._t_CannotCreateSessionException))
    Router._op_refreshSession = IcePy.Operation('refreshSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, True, None, (), (), (), None, (_M_Glacier2._t_SessionNotExistException,))
    Router._op_destroySession = IcePy.Operation('destroySession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, (_M_Glacier2._t_SessionNotExistException,))
    Router._op_getSessionTimeout = IcePy.Operation('getSessionTimeout', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_long, False, 0), ())
    Router._op_getACMTimeout = IcePy.Operation('getACMTimeout', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())

    _M_Glacier2.Router = Router
    del Router

    _M_Glacier2.RouterPrx = RouterPrx
    del RouterPrx

# End of module Glacier2

Ice.sliceChecksums["::Glacier2::Router"] = "dfe8817f11292a5582437c19a65b63"
Ice.sliceChecksums["::Glacier2::SessionNotExistException"] = "9b3392dc48a63f86d96c13662972328"



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Session.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_BuiltinSequences_ice
import Ice_Identity_ice
import Glacier2_SSLInfo_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Start of module Glacier2
__name__ = 'Glacier2'

if 'CannotCreateSessionException' not in _M_Glacier2.__dict__:
    _M_Glacier2.CannotCreateSessionException = Ice.createTempClass()
    class CannotCreateSessionException(Ice.UserException):
        """
        This exception is raised if an attempt to create a new session failed.
        Members:
        reason -- The reason why session creation has failed.
        """
        def __init__(self, reason=''):
            self.reason = reason

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'Glacier2::CannotCreateSessionException'

    _M_Glacier2._t_CannotCreateSessionException = IcePy.defineException('::Glacier2::CannotCreateSessionException', CannotCreateSessionException, (), True, None, (('reason', (), IcePy._t_string, False, 0),))
    CannotCreateSessionException._ice_type = _M_Glacier2._t_CannotCreateSessionException

    _M_Glacier2.CannotCreateSessionException = CannotCreateSessionException
    del CannotCreateSessionException

if 'Session' not in _M_Glacier2.__dict__:
    _M_Glacier2.Session = Ice.createTempClass()
    class Session(Ice.Object):
        """
        A client-visible session object, which is tied to the lifecycle of
        a Router.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.Session:
                raise RuntimeError('Glacier2.Session is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::Session', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Glacier2::Session'

        def ice_staticId():
            return '::Glacier2::Session'
        ice_staticId = staticmethod(ice_staticId)

        def destroy(self, current=None):
            """
            Destroy the session. This is called automatically when the router is destroyed.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_Session)

        __repr__ = __str__

    _M_Glacier2.SessionPrx = Ice.createTempClass()
    class SessionPrx(Ice.ObjectPrx):

        """
        Destroy the session. This is called automatically when the router is destroyed.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def destroy(self, _ctx=None):
            return _M_Glacier2.Session._op_destroy.invoke(self, ((), _ctx))

        """
        Destroy the session. This is called automatically when the router is destroyed.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_destroy(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.Session._op_destroy.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Destroy the session. This is called automatically when the router is destroyed.
        Arguments:
        """
        def end_destroy(self, _r):
            return _M_Glacier2.Session._op_destroy.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.SessionPrx.ice_checkedCast(proxy, '::Glacier2::Session', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.SessionPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::Session'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_SessionPrx = IcePy.defineProxy('::Glacier2::Session', SessionPrx)

    _M_Glacier2._t_Session = IcePy.defineClass('::Glacier2::Session', Session, -1, (), True, False, None, (), ())
    Session._ice_type = _M_Glacier2._t_Session

    Session._op_destroy = IcePy.Operation('destroy', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())

    _M_Glacier2.Session = Session
    del Session

    _M_Glacier2.SessionPrx = SessionPrx
    del SessionPrx

if 'StringSet' not in _M_Glacier2.__dict__:
    _M_Glacier2.StringSet = Ice.createTempClass()
    class StringSet(Ice.Object):
        """
        An object for managing the set of identity constraints for specific
        parts of object identity on a
        Session.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.StringSet:
                raise RuntimeError('Glacier2.StringSet is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::StringSet', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Glacier2::StringSet'

        def ice_staticId():
            return '::Glacier2::StringSet'
        ice_staticId = staticmethod(ice_staticId)

        def add(self, additions, current=None):
            """
            Add a sequence of strings to this set of constraints. Order is
            not preserved and duplicates are implicitly removed.
            Arguments:
            additions -- The sequence of strings to be added.
            current -- The Current object for the invocation.
            """
            pass

        def remove(self, deletions, current=None):
            """
            Remove a sequence of strings from this set of constraints. No
            errors are returned if an entry is not found.
            Arguments:
            deletions -- The sequence of strings to be removed.
            current -- The Current object for the invocation.
            """
            pass

        def get(self, current=None):
            """
            Returns a sequence of strings describing the constraints in this
            set.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The sequence of strings for this set.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_StringSet)

        __repr__ = __str__

    _M_Glacier2.StringSetPrx = Ice.createTempClass()
    class StringSetPrx(Ice.ObjectPrx):

        """
        Add a sequence of strings to this set of constraints. Order is
        not preserved and duplicates are implicitly removed.
        Arguments:
        additions -- The sequence of strings to be added.
        _ctx -- The request context for the invocation.
        """
        def add(self, additions, _ctx=None):
            return _M_Glacier2.StringSet._op_add.invoke(self, ((additions, ), _ctx))

        """
        Add a sequence of strings to this set of constraints. Order is
        not preserved and duplicates are implicitly removed.
        Arguments:
        additions -- The sequence of strings to be added.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_add(self, additions, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.StringSet._op_add.begin(self, ((additions, ), _response, _ex, _sent, _ctx))

        """
        Add a sequence of strings to this set of constraints. Order is
        not preserved and duplicates are implicitly removed.
        Arguments:
        additions -- The sequence of strings to be added.
        """
        def end_add(self, _r):
            return _M_Glacier2.StringSet._op_add.end(self, _r)

        """
        Remove a sequence of strings from this set of constraints. No
        errors are returned if an entry is not found.
        Arguments:
        deletions -- The sequence of strings to be removed.
        _ctx -- The request context for the invocation.
        """
        def remove(self, deletions, _ctx=None):
            return _M_Glacier2.StringSet._op_remove.invoke(self, ((deletions, ), _ctx))

        """
        Remove a sequence of strings from this set of constraints. No
        errors are returned if an entry is not found.
        Arguments:
        deletions -- The sequence of strings to be removed.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_remove(self, deletions, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.StringSet._op_remove.begin(self, ((deletions, ), _response, _ex, _sent, _ctx))

        """
        Remove a sequence of strings from this set of constraints. No
        errors are returned if an entry is not found.
        Arguments:
        deletions -- The sequence of strings to be removed.
        """
        def end_remove(self, _r):
            return _M_Glacier2.StringSet._op_remove.end(self, _r)

        """
        Returns a sequence of strings describing the constraints in this
        set.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The sequence of strings for this set.
        """
        def get(self, _ctx=None):
            return _M_Glacier2.StringSet._op_get.invoke(self, ((), _ctx))

        """
        Returns a sequence of strings describing the constraints in this
        set.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_get(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.StringSet._op_get.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns a sequence of strings describing the constraints in this
        set.
        Arguments:
        Returns: The sequence of strings for this set.
        """
        def end_get(self, _r):
            return _M_Glacier2.StringSet._op_get.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.StringSetPrx.ice_checkedCast(proxy, '::Glacier2::StringSet', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.StringSetPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::StringSet'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_StringSetPrx = IcePy.defineProxy('::Glacier2::StringSet', StringSetPrx)

    _M_Glacier2._t_StringSet = IcePy.defineClass('::Glacier2::StringSet', StringSet, -1, (), True, False, None, (), ())
    StringSet._ice_type = _M_Glacier2._t_StringSet

    StringSet._op_add = IcePy.Operation('add', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_Ice._t_StringSeq, False, 0),), (), None, ())
    StringSet._op_remove = IcePy.Operation('remove', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_Ice._t_StringSeq, False, 0),), (), None, ())
    StringSet._op_get = IcePy.Operation('get', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), _M_Ice._t_StringSeq, False, 0), ())

    _M_Glacier2.StringSet = StringSet
    del StringSet

    _M_Glacier2.StringSetPrx = StringSetPrx
    del StringSetPrx

if 'IdentitySet' not in _M_Glacier2.__dict__:
    _M_Glacier2.IdentitySet = Ice.createTempClass()
    class IdentitySet(Ice.Object):
        """
        An object for managing the set of object identity constraints on a
        Session.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.IdentitySet:
                raise RuntimeError('Glacier2.IdentitySet is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::IdentitySet', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Glacier2::IdentitySet'

        def ice_staticId():
            return '::Glacier2::IdentitySet'
        ice_staticId = staticmethod(ice_staticId)

        def add(self, additions, current=None):
            """
            Add a sequence of Ice identities to this set of constraints. Order is
            not preserved and duplicates are implicitly removed.
            Arguments:
            additions -- The sequence of Ice identities to be added.
            current -- The Current object for the invocation.
            """
            pass

        def remove(self, deletions, current=None):
            """
            Remove a sequence of identities from this set of constraints. No
            errors are returned if an entry is not found.
            Arguments:
            deletions -- The sequence of Ice identities to be removed.
            current -- The Current object for the invocation.
            """
            pass

        def get(self, current=None):
            """
            Returns a sequence of identities describing the constraints in this
            set.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The sequence of Ice identities for this set.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_IdentitySet)

        __repr__ = __str__

    _M_Glacier2.IdentitySetPrx = Ice.createTempClass()
    class IdentitySetPrx(Ice.ObjectPrx):

        """
        Add a sequence of Ice identities to this set of constraints. Order is
        not preserved and duplicates are implicitly removed.
        Arguments:
        additions -- The sequence of Ice identities to be added.
        _ctx -- The request context for the invocation.
        """
        def add(self, additions, _ctx=None):
            return _M_Glacier2.IdentitySet._op_add.invoke(self, ((additions, ), _ctx))

        """
        Add a sequence of Ice identities to this set of constraints. Order is
        not preserved and duplicates are implicitly removed.
        Arguments:
        additions -- The sequence of Ice identities to be added.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_add(self, additions, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.IdentitySet._op_add.begin(self, ((additions, ), _response, _ex, _sent, _ctx))

        """
        Add a sequence of Ice identities to this set of constraints. Order is
        not preserved and duplicates are implicitly removed.
        Arguments:
        additions -- The sequence of Ice identities to be added.
        """
        def end_add(self, _r):
            return _M_Glacier2.IdentitySet._op_add.end(self, _r)

        """
        Remove a sequence of identities from this set of constraints. No
        errors are returned if an entry is not found.
        Arguments:
        deletions -- The sequence of Ice identities to be removed.
        _ctx -- The request context for the invocation.
        """
        def remove(self, deletions, _ctx=None):
            return _M_Glacier2.IdentitySet._op_remove.invoke(self, ((deletions, ), _ctx))

        """
        Remove a sequence of identities from this set of constraints. No
        errors are returned if an entry is not found.
        Arguments:
        deletions -- The sequence of Ice identities to be removed.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_remove(self, deletions, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.IdentitySet._op_remove.begin(self, ((deletions, ), _response, _ex, _sent, _ctx))

        """
        Remove a sequence of identities from this set of constraints. No
        errors are returned if an entry is not found.
        Arguments:
        deletions -- The sequence of Ice identities to be removed.
        """
        def end_remove(self, _r):
            return _M_Glacier2.IdentitySet._op_remove.end(self, _r)

        """
        Returns a sequence of identities describing the constraints in this
        set.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The sequence of Ice identities for this set.
        """
        def get(self, _ctx=None):
            return _M_Glacier2.IdentitySet._op_get.invoke(self, ((), _ctx))

        """
        Returns a sequence of identities describing the constraints in this
        set.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_get(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.IdentitySet._op_get.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns a sequence of identities describing the constraints in this
        set.
        Arguments:
        Returns: The sequence of Ice identities for this set.
        """
        def end_get(self, _r):
            return _M_Glacier2.IdentitySet._op_get.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.IdentitySetPrx.ice_checkedCast(proxy, '::Glacier2::IdentitySet', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.IdentitySetPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::IdentitySet'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_IdentitySetPrx = IcePy.defineProxy('::Glacier2::IdentitySet', IdentitySetPrx)

    _M_Glacier2._t_IdentitySet = IcePy.defineClass('::Glacier2::IdentitySet', IdentitySet, -1, (), True, False, None, (), ())
    IdentitySet._ice_type = _M_Glacier2._t_IdentitySet

    IdentitySet._op_add = IcePy.Operation('add', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_Ice._t_IdentitySeq, False, 0),), (), None, ())
    IdentitySet._op_remove = IcePy.Operation('remove', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_Ice._t_IdentitySeq, False, 0),), (), None, ())
    IdentitySet._op_get = IcePy.Operation('get', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), _M_Ice._t_IdentitySeq, False, 0), ())

    _M_Glacier2.IdentitySet = IdentitySet
    del IdentitySet

    _M_Glacier2.IdentitySetPrx = IdentitySetPrx
    del IdentitySetPrx

if 'SessionControl' not in _M_Glacier2.__dict__:
    _M_Glacier2.SessionControl = Ice.createTempClass()
    class SessionControl(Ice.Object):
        """
        An administrative session control object, which is tied to the
        lifecycle of a Session.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.SessionControl:
                raise RuntimeError('Glacier2.SessionControl is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::SessionControl', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Glacier2::SessionControl'

        def ice_staticId():
            return '::Glacier2::SessionControl'
        ice_staticId = staticmethod(ice_staticId)

        def categories(self, current=None):
            """
            Access the object that manages the allowable categories
            for object identities for this session.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A StringSet object.
            """
            pass

        def adapterIds(self, current=None):
            """
            Access the object that manages the allowable adapter identities
            for objects for this session.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A StringSet object.
            """
            pass

        def identities(self, current=None):
            """
            Access the object that manages the allowable object identities
            for this session.
            Arguments:
            current -- The Current object for the invocation.
            Returns: An IdentitySet object.
            """
            pass

        def getSessionTimeout(self, current=None):
            """
            Get the session timeout.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The timeout.
            """
            pass

        def destroy(self, current=None):
            """
            Destroy the associated session.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_SessionControl)

        __repr__ = __str__

    _M_Glacier2.SessionControlPrx = Ice.createTempClass()
    class SessionControlPrx(Ice.ObjectPrx):

        """
        Access the object that manages the allowable categories
        for object identities for this session.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: A StringSet object.
        """
        def categories(self, _ctx=None):
            return _M_Glacier2.SessionControl._op_categories.invoke(self, ((), _ctx))

        """
        Access the object that manages the allowable categories
        for object identities for this session.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_categories(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.SessionControl._op_categories.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Access the object that manages the allowable categories
        for object identities for this session.
        Arguments:
        Returns: A StringSet object.
        """
        def end_categories(self, _r):
            return _M_Glacier2.SessionControl._op_categories.end(self, _r)

        """
        Access the object that manages the allowable adapter identities
        for objects for this session.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: A StringSet object.
        """
        def adapterIds(self, _ctx=None):
            return _M_Glacier2.SessionControl._op_adapterIds.invoke(self, ((), _ctx))

        """
        Access the object that manages the allowable adapter identities
        for objects for this session.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_adapterIds(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.SessionControl._op_adapterIds.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Access the object that manages the allowable adapter identities
        for objects for this session.
        Arguments:
        Returns: A StringSet object.
        """
        def end_adapterIds(self, _r):
            return _M_Glacier2.SessionControl._op_adapterIds.end(self, _r)

        """
        Access the object that manages the allowable object identities
        for this session.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: An IdentitySet object.
        """
        def identities(self, _ctx=None):
            return _M_Glacier2.SessionControl._op_identities.invoke(self, ((), _ctx))

        """
        Access the object that manages the allowable object identities
        for this session.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_identities(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.SessionControl._op_identities.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Access the object that manages the allowable object identities
        for this session.
        Arguments:
        Returns: An IdentitySet object.
        """
        def end_identities(self, _r):
            return _M_Glacier2.SessionControl._op_identities.end(self, _r)

        """
        Get the session timeout.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The timeout.
        """
        def getSessionTimeout(self, _ctx=None):
            return _M_Glacier2.SessionControl._op_getSessionTimeout.invoke(self, ((), _ctx))

        """
        Get the session timeout.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getSessionTimeout(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.SessionControl._op_getSessionTimeout.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the session timeout.
        Arguments:
        Returns: The timeout.
        """
        def end_getSessionTimeout(self, _r):
            return _M_Glacier2.SessionControl._op_getSessionTimeout.end(self, _r)

        """
        Destroy the associated session.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def destroy(self, _ctx=None):
            return _M_Glacier2.SessionControl._op_destroy.invoke(self, ((), _ctx))

        """
        Destroy the associated session.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_destroy(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.SessionControl._op_destroy.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Destroy the associated session.
        Arguments:
        """
        def end_destroy(self, _r):
            return _M_Glacier2.SessionControl._op_destroy.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.SessionControlPrx.ice_checkedCast(proxy, '::Glacier2::SessionControl', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.SessionControlPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::SessionControl'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_SessionControlPrx = IcePy.defineProxy('::Glacier2::SessionControl', SessionControlPrx)

    _M_Glacier2._t_SessionControl = IcePy.defineClass('::Glacier2::SessionControl', SessionControl, -1, (), True, False, None, (), ())
    SessionControl._ice_type = _M_Glacier2._t_SessionControl

    SessionControl._op_categories = IcePy.Operation('categories', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_Glacier2._t_StringSetPrx, False, 0), ())
    SessionControl._op_adapterIds = IcePy.Operation('adapterIds', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_Glacier2._t_StringSetPrx, False, 0), ())
    SessionControl._op_identities = IcePy.Operation('identities', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_Glacier2._t_IdentitySetPrx, False, 0), ())
    SessionControl._op_getSessionTimeout = IcePy.Operation('getSessionTimeout', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    SessionControl._op_destroy = IcePy.Operation('destroy', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())

    _M_Glacier2.SessionControl = SessionControl
    del SessionControl

    _M_Glacier2.SessionControlPrx = SessionControlPrx
    del SessionControlPrx

if 'SessionManager' not in _M_Glacier2.__dict__:
    _M_Glacier2.SessionManager = Ice.createTempClass()
    class SessionManager(Ice.Object):
        """
        The session manager for username/password authenticated users that
        is responsible for managing Session objects. New session objects
        are created by the Router object calling on an application-provided
        session manager. If no session manager is provided by the application,
        no client-visible sessions are passed to the client.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.SessionManager:
                raise RuntimeError('Glacier2.SessionManager is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::SessionManager', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Glacier2::SessionManager'

        def ice_staticId():
            return '::Glacier2::SessionManager'
        ice_staticId = staticmethod(ice_staticId)

        def create(self, userId, control, current=None):
            """
            Create a new session.
            Arguments:
            userId -- The user id for the session.
            control -- A proxy to the session control object.
            current -- The Current object for the invocation.
            Returns: A proxy to the newly created session.
            Throws:
            CannotCreateSessionException -- Raised if the session cannot be created.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_SessionManager)

        __repr__ = __str__

    _M_Glacier2.SessionManagerPrx = Ice.createTempClass()
    class SessionManagerPrx(Ice.ObjectPrx):

        """
        Create a new session.
        Arguments:
        userId -- The user id for the session.
        control -- A proxy to the session control object.
        _ctx -- The request context for the invocation.
        Returns: A proxy to the newly created session.
        Throws:
        CannotCreateSessionException -- Raised if the session cannot be created.
        """
        def create(self, userId, control, _ctx=None):
            return _M_Glacier2.SessionManager._op_create.invoke(self, ((userId, control), _ctx))

        """
        Create a new session.
        Arguments:
        userId -- The user id for the session.
        control -- A proxy to the session control object.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_create(self, userId, control, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.SessionManager._op_create.begin(self, ((userId, control), _response, _ex, _sent, _ctx))

        """
        Create a new session.
        Arguments:
        userId -- The user id for the session.
        control -- A proxy to the session control object.
        Returns: A proxy to the newly created session.
        Throws:
        CannotCreateSessionException -- Raised if the session cannot be created.
        """
        def end_create(self, _r):
            return _M_Glacier2.SessionManager._op_create.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.SessionManagerPrx.ice_checkedCast(proxy, '::Glacier2::SessionManager', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.SessionManagerPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::SessionManager'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_SessionManagerPrx = IcePy.defineProxy('::Glacier2::SessionManager', SessionManagerPrx)

    _M_Glacier2._t_SessionManager = IcePy.defineClass('::Glacier2::SessionManager', SessionManager, -1, (), True, False, None, (), ())
    SessionManager._ice_type = _M_Glacier2._t_SessionManager

    SessionManager._op_create = IcePy.Operation('create', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, Ice.FormatType.SlicedFormat, (), (((), IcePy._t_string, False, 0), ((), _M_Glacier2._t_SessionControlPrx, False, 0)), (), ((), _M_Glacier2._t_SessionPrx, False, 0), (_M_Glacier2._t_CannotCreateSessionException,))

    _M_Glacier2.SessionManager = SessionManager
    del SessionManager

    _M_Glacier2.SessionManagerPrx = SessionManagerPrx
    del SessionManagerPrx

if 'SSLSessionManager' not in _M_Glacier2.__dict__:
    _M_Glacier2.SSLSessionManager = Ice.createTempClass()
    class SSLSessionManager(Ice.Object):
        """
        The session manager for SSL authenticated users that is
        responsible for managing Session objects. New session objects are
        created by the Router object calling on an application-provided
        session manager. If no session manager is provided by the
        application, no client-visible sessions are passed to the client.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Glacier2.SSLSessionManager:
                raise RuntimeError('Glacier2.SSLSessionManager is an abstract class')

        def ice_ids(self, current=None):
            return ('::Glacier2::SSLSessionManager', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Glacier2::SSLSessionManager'

        def ice_staticId():
            return '::Glacier2::SSLSessionManager'
        ice_staticId = staticmethod(ice_staticId)

        def create(self, info, control, current=None):
            """
            Create a new session.
            Arguments:
            info -- The SSL info.
            control -- A proxy to the session control object.
            current -- The Current object for the invocation.
            Returns: A proxy to the newly created session.
            Throws:
            CannotCreateSessionException -- Raised if the session cannot be created.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Glacier2._t_SSLSessionManager)

        __repr__ = __str__

    _M_Glacier2.SSLSessionManagerPrx = Ice.createTempClass()
    class SSLSessionManagerPrx(Ice.ObjectPrx):

        """
        Create a new session.
        Arguments:
        info -- The SSL info.
        control -- A proxy to the session control object.
        _ctx -- The request context for the invocation.
        Returns: A proxy to the newly created session.
        Throws:
        CannotCreateSessionException -- Raised if the session cannot be created.
        """
        def create(self, info, control, _ctx=None):
            return _M_Glacier2.SSLSessionManager._op_create.invoke(self, ((info, control), _ctx))

        """
        Create a new session.
        Arguments:
        info -- The SSL info.
        control -- A proxy to the session control object.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_create(self, info, control, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Glacier2.SSLSessionManager._op_create.begin(self, ((info, control), _response, _ex, _sent, _ctx))

        """
        Create a new session.
        Arguments:
        info -- The SSL info.
        control -- A proxy to the session control object.
        Returns: A proxy to the newly created session.
        Throws:
        CannotCreateSessionException -- Raised if the session cannot be created.
        """
        def end_create(self, _r):
            return _M_Glacier2.SSLSessionManager._op_create.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Glacier2.SSLSessionManagerPrx.ice_checkedCast(proxy, '::Glacier2::SSLSessionManager', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Glacier2.SSLSessionManagerPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Glacier2::SSLSessionManager'
        ice_staticId = staticmethod(ice_staticId)

    _M_Glacier2._t_SSLSessionManagerPrx = IcePy.defineProxy('::Glacier2::SSLSessionManager', SSLSessionManagerPrx)

    _M_Glacier2._t_SSLSessionManager = IcePy.defineClass('::Glacier2::SSLSessionManager', SSLSessionManager, -1, (), True, False, None, (), ())
    SSLSessionManager._ice_type = _M_Glacier2._t_SSLSessionManager

    SSLSessionManager._op_create = IcePy.Operation('create', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, Ice.FormatType.SlicedFormat, (), (((), _M_Glacier2._t_SSLInfo, False, 0), ((), _M_Glacier2._t_SessionControlPrx, False, 0)), (), ((), _M_Glacier2._t_SessionPrx, False, 0), (_M_Glacier2._t_CannotCreateSessionException,))

    _M_Glacier2.SSLSessionManager = SSLSessionManager
    del SSLSessionManager

    _M_Glacier2.SSLSessionManagerPrx = SSLSessionManagerPrx
    del SSLSessionManagerPrx

# End of module Glacier2

Ice.sliceChecksums["::Glacier2::CannotCreateSessionException"] = "f3cf2057ea305ed04671164dfaeb6d95"
Ice.sliceChecksums["::Glacier2::IdentitySet"] = "622e43adfd1f535abaee1b089583847"
Ice.sliceChecksums["::Glacier2::SSLSessionManager"] = "4eb77cf437452f5296bf24dda4967d"
Ice.sliceChecksums["::Glacier2::Session"] = "8e47590dc18dd2a2e2e7749c941fc7"
Ice.sliceChecksums["::Glacier2::SessionControl"] = "83a11c547492ddc72db70659938222"
Ice.sliceChecksums["::Glacier2::SessionManager"] = "f3c67f2f29415754c0f1ccc1ab5558e"
Ice.sliceChecksums["::Glacier2::StringSet"] = "1b46953cdce5ef8b6fe92056adf3fda0"
